"use strict";
// *****************************************************************************
// Copyright (C) 2021 TypeFox and others.
//
// This program and the accompanying materials are made available under the
// terms of the Eclipse Public License v. 2.0 which is available at
// http://www.eclipse.org/legal/epl-2.0.
//
// This Source Code may also be made available under the following Secondary
// Licenses when the conditions for such availability set forth in the Eclipse
// Public License v. 2.0 are satisfied: GNU General Public License, version 2
// with the GNU Classpath Exception which is available at
// https://www.gnu.org/software/classpath/license.html.
//
// SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0
// *****************************************************************************
Object.defineProperty(exports, "__esModule", { value: true });
exports.Localization = exports.AsyncLocalizationProvider = exports.localizationPath = void 0;
exports.localizationPath = '/services/i18n';
exports.AsyncLocalizationProvider = Symbol('AsyncLocalizationProvider');
var Localization;
(function (Localization) {
    const formatRegexp = /{([^}]+)}/g;
    function format(message, args) {
        return message.replace(formatRegexp, (match, group) => { var _a; return ((_a = args[group]) !== null && _a !== void 0 ? _a : match); });
    }
    Localization.format = format;
    function localize(localization, key, defaultValue, ...args) {
        let value = defaultValue;
        if (localization) {
            const translation = localization.translations[key];
            if (translation) {
                value = normalize(translation);
            }
        }
        return format(value, args);
    }
    Localization.localize = localize;
    /**
     * This function normalizes values from VSCode's localizations, which often contain additional mnemonics (`&&`).
     * The normalization removes the mnemonics from the input string.
     *
     * @param value Localization value coming from VSCode
     * @returns A normalized localized value
     */
    function normalize(value) {
        return value.replace(/&&/g, '');
    }
    Localization.normalize = normalize;
    function transformKey(key) {
        let nlsKey = key;
        const keySlashIndex = key.lastIndexOf('/');
        if (keySlashIndex >= 0) {
            nlsKey = key.substring(keySlashIndex + 1);
        }
        return nlsKey;
    }
    Localization.transformKey = transformKey;
})(Localization = exports.Localization || (exports.Localization = {}));
//# sourceMappingURL=localization.js.map